# Pygame Made Easy

This project aims to some of the complexity of using Pygame for beginner level programmers.

This project has been initially developed for use within my own classes that I teach but I hope it might find use for others too.

## PROJECT HOME

* [PygameMadeEasy](https://pbaumgarten.com/pygamemadeeasy)

## INSTALL

```
pip install pygame pygamemadeeasy
```

## USAGE

Sorry, documentation still to come :-(

## AUTHOR

* [Paul Baumgarten](https://pbaumgarten.com/)

## LICENSE

MIT License (C) 2019 Paul Baumgarten

